.. _tips_tricks_index:
.. _playbooks_best_practices:

#######################
Ansible tips and tricks
#######################

.. note::

    **Making Open Source More Inclusive**

    Red Hat is committed to replacing problematic language in our code, documentation, and web properties. We are beginning with these four terms: master, slave, blacklist, and whitelist. We ask that you open an issue or pull request if you come upon a term that we have missed. For more details, see `our CTO Chris Wright's message <https://www.redhat.com/en/blog/making-open-source-more-inclusive-eradicating-problematic-language>`_.

Welcome to the Ansible tips and tricks guide.
These tips and tricks have helped us optimize our Ansible usage and we offer them here as suggestions.
We hope they will help you organize content, write playbooks, maintain inventory, and execute Ansible.
Ultimately, though, you should use Ansible in the way that makes most sense for your organization and your goals.

.. toctree::
   :maxdepth: 2
   
   ansible_tips_tricks
   sample_setup